Page 151 of The Secret Side Of History Mystery Babylon, 209P | thedailydialectics
Description: Document: The Secret Side Of History Mystery Babylon, 209P
Keywords: The Secret Side Of History Mystery Babylon, 209P

# The Secret Side Of History Mystery Babylon, 209P — Page 151

Home

    There are several aspects of this CFR supported
    United Nations war against Muslims that Christians in

    America need to know. One is that the vast majority of
    true Muslims are peaceful, God-fearing people. The 800
    million Muslims in the world stand in the way of a
    godless one world government, as do millions of
    Christians. Babylon's plan may be to promote warfare
    between the two by secretly promoting terrorism and
    placing the blame on the majority.

    Another serious consideration for Christians in

    America is the increasing number of media attacks
    against "fundamentalism" under which are lumped
    groups like Operation Rescue, Zionists, and Muslims. If
    not stopped, UN troops may be used to wage war in the
    U. S. against Christians and Muslims, both being labeled
    as "Fundamentalists."

    The tragic events at Waco may have been a test run
    to see if Americans have been sufficiently conditioned to

    accept military attacks by the government upon religion.
    As a warning to what may be planned, consider
    statements made by President Clinton (a member of the
    CFR) immediately after Waco:

    I hope very much that others who will be tempted to
    join cults and become involved with people like Koresh
    will be deterred by the horrible scenes they have seen.

    There is, unfortunately, a rise in this sort of
    fanaticism all over the world. And we may have to
    confront it again.”

    146

    The Secret Side of History